@@ -4,7 +4,7 @@ Main interface for apigatewayv2 service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_apigatewayv2 import (
         ApiGatewayV2Client,
         Client,
@@ -20,10 +20,8 @@ Usage::
         GetStagesPaginator,
     )
 
-    session = boto3.Session()
-
-    client: ApiGatewayV2Client = boto3.client("apigatewayv2")
-    session_client: ApiGatewayV2Client = session.client("apigatewayv2")
+    session = Session()
+    client: ApiGatewayV2Client = session.client("apigatewayv2")
 
     get_apis_paginator: GetApisPaginator = client.get_paginator("get_apis")
     get_authorizers_paginator: GetAuthorizersPaginator = client.get_paginator("get_authorizers")
@@ -37,8 +35,8 @@ Usage::
     get_stages_paginator: GetStagesPaginator = client.get_paginator("get_stages")
     ```
 """
-from mypy_boto3_apigatewayv2.client import ApiGatewayV2Client
-from mypy_boto3_apigatewayv2.paginator import (
+from .client import ApiGatewayV2Client
+from .paginator import (
     GetApisPaginator,
     GetAuthorizersPaginator,
     GetDeploymentsPaginator,
